nameko.legacy package
=====================

Submodules
----------

.. toctree::

   nameko.legacy.channelhandler
   nameko.legacy.common
   nameko.legacy.consuming
   nameko.legacy.context
   nameko.legacy.decorators
   nameko.legacy.nova
   nameko.legacy.proxy
   nameko.legacy.responses
   nameko.legacy.testing

Module contents
---------------

.. automodule:: nameko.legacy
    :members:
    :undoc-members:
    :show-inheritance:
